import { Component, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { ChatMessageService } from './chat.service';
import { ChatMessageDTO } from './chat.model';
import { ReviewService } from 'app/entities/review/service/review.service';

@Component({
  selector: 'jhi-reviewing-chat',
  templateUrl: './reviewing-chat.component.html',
  styleUrls: ['./reviewing-chat.component.scss'],
})
export class ReviewingChatComponent implements OnInit {
  reviewId: string | undefined;
  chatMessages: ChatMessageDTO[] = []; // Initialized as an empty array
  messageText = '';
  reviewResource = '';

  constructor(private route: ActivatedRoute, private chatMessageService: ChatMessageService, private reviewService: ReviewService) {}

  ngOnInit(): void {
    // Subscribe to the route parameters and extract the review ID
    this.route.params.subscribe(params => {
      this.reviewId = params['id'];

      // Load the chat messages for this review
      if (this.reviewId) {
        this.chatMessageService.findByReview(+this.reviewId).subscribe(data => {
          this.chatMessages = data;
        });
        // Get review resource
        this.reviewService.getReviewResource(+this.reviewId).subscribe(resource => {
          this.reviewResource = resource;
          console.log(this.reviewResource);
        });
      }
    });
  }

  goBack(): void {
    window.history.back();
  }

  sendMessage(): void {
    if (this.reviewId && this.messageText.trim().length > 0) {
      const chatMessageDTO: ChatMessageDTO = {
        messageText: this.messageText,
        reviewID: +this.reviewId,
        sentByUser: true,
        senderName: 'User Name',
      };

      this.chatMessageService.saveChatMessage(chatMessageDTO).subscribe(newMessage => {
        // Add the new message to the chat messages
        this.chatMessages.push(newMessage);

        // Clear the message text
        this.messageText = '';
      });
    }
  }
}
