import { Injectable } from '@angular/core';
import { HttpResponse } from '@angular/common/http';
import { Resolve, ActivatedRouteSnapshot, Router } from '@angular/router';
import { Observable, of, EMPTY } from 'rxjs';
import { mergeMap } from 'rxjs/operators';

import { ISavedSearches } from '../saved-searches.model';
import { SavedSearchesService } from '../service/saved-searches.service';

@Injectable({ providedIn: 'root' })
export class SavedSearchesRoutingResolveService implements Resolve<ISavedSearches | null> {
  constructor(protected service: SavedSearchesService, protected router: Router) {}

  resolve(route: ActivatedRouteSnapshot): Observable<ISavedSearches | null | never> {
    const id = route.params['id'];
    if (id) {
      return this.service.find(id).pipe(
        mergeMap((savedSearches: HttpResponse<ISavedSearches>) => {
          if (savedSearches.body) {
            return of(savedSearches.body);
          } else {
            this.router.navigate(['404']);
            return EMPTY;
          }
        })
      );
    }
    return of(null);
  }
}
