import { Injectable } from '@angular/core';
import { HttpResponse } from '@angular/common/http';
import { Resolve, ActivatedRouteSnapshot, Router } from '@angular/router';
import { Observable, of, EMPTY } from 'rxjs';
import { mergeMap } from 'rxjs/operators';

import { IWatchListEntry, WatchListEntry } from '../watch-list-entry.model';
import { WatchListEntryService } from '../service/watch-list-entry.service';

@Injectable({ providedIn: 'root' })
export class WatchListEntryRoutingResolveService implements Resolve<IWatchListEntry> {
  constructor(protected service: WatchListEntryService, protected router: Router) {}

  resolve(route: ActivatedRouteSnapshot): Observable<IWatchListEntry> | Observable<never> {
    const id = route.params['id'];
    if (id) {
      return this.service.find(id).pipe(
        mergeMap((watchListEntry: HttpResponse<WatchListEntry>) => {
          if (watchListEntry.body) {
            return of(watchListEntry.body);
          } else {
            this.router.navigate(['404']);
            return EMPTY;
          }
        })
      );
    }
    return of(new WatchListEntry());
  }
}
